using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using System.Diagnostics;
using System.Text;

using Syncfusion.XlsIO;
using Syncfusion.XlsIO.Implementation;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Windows.Forms.Tools;
using Syncfusion.Drawing;
using Syncfusion.GridExcelConverter;

namespace ComboGDBG
{
	/// <summary>
	/// Summary description for ADVExcelExport.
	/// </summary>
	public class ADVExcelExportControl: GridExcelConverterControl
	{
		private int iStartColIndex = -1;
		private int iEndColIndex = -1;

		private int iExtraColumnHeader = 0;

		public ADVExcelExportControl():base()
		{
			 
		}
		public void ADVGridToExcel( GridModel grid, IWorksheet sheet, ConverterOptions options )
		{
			if( options == ConverterOptions.RowHeaders) 
				this.GridToExcel(grid,sheet,ConverterOptions.ColumnHeaders); 
			else if( options == ConverterOptions.ColumnHeaders) 
				this.GridToExcel(grid,sheet,ConverterOptions.RowHeaders); 
			else
				this.GridToExcel(grid,sheet,options); 

		}
		public void ADVGridToExcel( GridModel grid, string fileName, ConverterOptions options )
		{
			if( options == ConverterOptions.RowHeaders) 
				this.GridToExcel(grid,fileName,ConverterOptions.ColumnHeaders); 
			else if( options == ConverterOptions.ColumnHeaders) 
				this.GridToExcel(grid,fileName,ConverterOptions.RowHeaders); 
			else
				this.GridToExcel(grid,fileName,options); 
		}
		
		public void SelectedCellsExport(GridModel model,string FileName,ConverterOptions options )
		{
			ExcelEngine engine = CreateEngine();
			IWorkbook book = engine.Excel.Workbooks.Create( 1 );
			IWorksheet sheet = book.Worksheets[ 0 ];
			GridRangeInfoList list = model.SelectedRanges;
			if( options == ConverterOptions.RowHeaders) 
				iExtraColumnHeader = 1;
			foreach( GridRangeInfo range in list)
			{
				switch( range.RangeType)
				{
					case GridRangeInfoType.Cells:  
						ExportCells(range,model,sheet);
						break;
					case GridRangeInfoType.Cols:  
						ExportCells(GridRangeInfo.Cells(1,range.Left,model.RowCount,range.Right),model,sheet);    
						break;
					case GridRangeInfoType.Rows:  
						ExportCells(GridRangeInfo.Cells(range.Top,1,range.Bottom,model.ColCount),model,sheet);
						break;
					case GridRangeInfoType.Table:
						book.Close(); 
						this.GridToExcel(model,FileName,options); 
						return;
				}
			}
			if( options == ConverterOptions.RowHeaders) 
				ExportColumnHeaders(model,sheet);

			book.SaveAs(FileName);  
			book.Close(); 
		}
		
		public void ExportCells(GridRangeInfo range, GridModel model, IWorksheet sheet)
		{
			if( iStartColIndex < range.Left)
				iStartColIndex = range.Left;
			if( iEndColIndex < range.Right)
				iEndColIndex = range.Right;
			

			for(int i = range.Top, iRowRange = 1 + iExtraColumnHeader ;i<= range.Bottom;i++,iRowRange++)
			{
                for(int j = range.Left,iColRange = 1 ;j<= range.Right;j++,iColRange++)
				{
					this.CopyStyle( model[i,j],sheet[iRowRange,iColRange]);
					sheet[iRowRange,iColRange].Text = model[i,j].FormattedText; 
				}
			}
		}

		public void ExportColumnHeaders( GridModel model, IWorksheet sheet)
		{
			for(int j = iStartColIndex,iColRange = 1 ;j<= iEndColIndex;j++,iColRange++)
			{
				this.CopyStyle( model[0,j],sheet[1,iColRange]);
				sheet[1,iColRange].Text = model[0,j].FormattedText; 
			}
		}
			
		
	}
}
